@@ -43,11 +43,11 @@ def getInput(config, one_seq=False):
     role_id_input = layers.Input(shape=(), dtype='int64', name='role_id_input')
 
     if one_seq:
-        sequence_id_input = layers.Input(shape=(1, maxlen,), dtype='int64', name='sequence_id_input')
+        sequence_id_input = layers.Input(shape=(1, maxlen,), dtype='float32', name='sequence_id_input')
         sequence_time_input = layers.Input(shape=(1, maxlen,), dtype='int64', name='sequence_time_input')
         sequence_time_gaps_input = layers.Input(shape=(1, maxlen,), dtype='int64', name='sequence_time_gaps_input')
     else:
-        sequence_id_input = layers.Input(shape=(seq_num, maxlen,), dtype='int64', name='sequence_id_input')
+        sequence_id_input = layers.Input(shape=(seq_num, maxlen,), dtype='float32', name='sequence_id_input')
         sequence_time_input = layers.Input(shape=(seq_num, maxlen,), dtype='int64', name='sequence_time_input')
         sequence_time_gaps_input = layers.Input(shape=(seq_num, maxlen,), dtype='int64', name='sequence_time_gaps_input')
     if is_serving:
